diff --git a/tests/test_mpsd_software.py b/tests/test_mpsd_software.py
index 79fc35cea3ee48a3f7f625abd3495bd607bcf51c..7aae7fe45420b5cd0e04f6082898c244bf30e257 100644
--- a/tests/test_mpsd_software.py
+++ b/tests/test_mpsd_software.py
@@ -192,7 +192,7 @@ def test_record_script_execution_summary(tmp_path):
 
 def test_install_environment_wrong_package_set(tmp_path):
     """Test exception is raised for non-existing package_set."""
     # exits with exit code 1 when wrong package_sets are provided
     with pytest.raises(SystemExit) as e:
         mod.install_environment(
             mpsd_release="dev-23a",
@@ -200,7 +200,7 @@ def test_install_environment_wrong_package_set(tmp_path):
             root_dir=(tmp_path),
         )
     assert e.type == SystemExit
-    assert e.value.code == 1
+    assert e.value.code == 20
 
 
 def test_install_environment_wrong_mpsd_release(tmp_path):
@@ -192,7 +192,7 @@ def test_record_script_execution_summary(tmp_path):
 def test_install_environment_wrong_package_set(tmp_path):
     """Test exception is raised for non-existing package_set."""
-    # exits with exit code 1 when wrong package_sets are provided
+    # exits with exit code 20 when wrong package_sets are provided
     with pytest.raises(SystemExit) as e:
         mod.install_environment(